#!/usr/bin/env python
from argparse import ArgumentParser
import os
import sys

from create_updated_rules import create_updated_rules
from k8s_utils import (get_rules_from_api, sync_rules_configmaps,
                       upload_rules_changes)


def parse_args():
    parser = ArgumentParser()
    parser.add_argument('--old_cm',
                        help='path to old rules configMap mount directory')
    parser.add_argument('--new_cm',
                        help='path to new rules configMap mount directory')
    parser.add_argument('--output', default='/tmp/output/',
                        help='directory to place rule files to apply')
    parser.add_argument('--namespace', default='stacklight-alerts',
                        help='rules namespace to process')
    return parser.parse_args()


def main():
    args = parse_args()
    namespace = args.namespace
    new_cm_path = args.new_cm
    old_cm_path = args.old_cm
    output_path = '{}/{}'.format(args.output, namespace)
    current = '/tmp/stacklight-rules-api.yaml'

    os.makedirs(output_path, exist_ok=True)
    get_rules_from_api(namespace, current)

    create_updated_rules(namespace, new_cm_path, old_cm_path,
                         current, output_path)

    upload_rules_changes(output_path, namespace)
    new_cm_name = new_cm_path.split('/')[-1]
    old_cm_name = old_cm_path.split('/')[-1]
    sync_rules_configmaps(new_cm_name, old_cm_name)
    sys.stdout.write('Reconciling rules for {} namespace succeeded\n'.format(
        namespace))


if __name__ == '__main__':
    main()
