{{- define "alertmanager-webhook-servicenow" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "alertmanagerWebhookServicenow" | include "stacklight.logLevel" -}}

replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "alertmanagerWebhookServicenow" }}

httpProxyDiscovery:
  enabled: {{ .Values.global.proxy.enabled }}
  secretName: {{ .Values.global.proxy.secretName }}
  checksum: {{ .Values.global.proxy.hash }}
  ssl: {{ .Values.global.proxy.ssl }}

{{ $sn := .Values.alertmanagerSimpleConfig.serviceNow }}
env:
  SERVICENOW_INSTANCE: {{ $sn.auth.instance }}
  SERVICENOW_USERNAME: {{ $sn.auth.username }}
  SERVICENOW_PASSWORD: {{ $sn.auth.password }}
  SERVICENOW_TABLE: {{ $sn.incident_table }}
  SERVICENOW_API_VERSION: {{ $sn.api_version }}
  SERVICENOW_ALERT_ID_FIELD: {{ $sn.alert_id_field }}
  {{- if not .Values.cortexDev.enabled }}
  SERVICENOW_ADD_LINKS: {{ $sn.link_prometheus | quote }}
  {{- end }}
  {{- if $logLevel }}
  DEFAULT_LOGGER_LEVEL: {{ $logLevel }}
  {{- end }}
  {{- if .Values.clusterId }}
  CLUSTER_ID: {{ .Values.clusterId }}
  {{- end }}

image:
  {{- include "stacklight.getImage" (dict "root" . "image" "alertmanagerWebhookServicenow") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "alertmanagerWebhookServicenow") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "alertmanagerWebhookServicenow") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "alertmanagerWebhookServicenow") }}
livenessProbe:
  enabled: true
readinessProbe:
  enabled: true
{{- end }}
