{{- define "elasticsearch.curator" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "elasticsearchCurator" | include "stacklight.logLevel" -}}


{{- $loggingRetentionTime := merge (.Values.logging.retentionTime | default dict) (.Values.elasticsearch.retentionTime | default dict) }}
{{- $loggingRetentionTime = (dict "retentionTime" $loggingRetentionTime "logstashRetentionTime" .Values.elasticsearch.logstashRetentionTime ) }}

{{- $loggingRetentionTimeDefaultsSet := (include "stacklight.setRetentionDefaults" $loggingRetentionTime | fromYaml) }}

{{- $resultRetentionValues := dict }}
{{- range $indexType, $indexRetention := $loggingRetentionTimeDefaultsSet }}
  {{- $retentionValue := $indexRetention | toString }}
  {{- $resultRetentionValues := set $resultRetentionValues $indexType (include "stacklight.logsRetention" $retentionValue | fromYaml) }}
{{- end }}

{{- $esReplicas := 1 }}
{{- if .Values.highAvailabilityEnabled }}
  {{- $esReplicas = 3 }}
{{- end }}
cronjob:
  schedule: "{{ .Values.logging.cronJobSchedule | default .Values.elasticsearch.cronJobSchedule }}"
configMaps:
  config_yml: |-
    ---
    client:
      hosts:
      - opensearch-master
      port: 9200
{{- if $logLevel }}
    logging:
      loglevel: {{ $logLevel | quote }}
{{- end }}
  action_file_yml: |-
    ---
    actions:
      1:
        action: open
        description: "Open closed indices for later evaluation"
        filters: []
        options:
          continue_if_exception: true
          disable_action: false
          ignore_empty_list: true
      2:
        action: delete_indices
        description: "Delete log indices older than {{ $resultRetentionValues.logstash.count }} {{ $resultRetentionValues.logstash.unit  }} (based on index creation date)."
        filters:
        - filtertype: pattern
          kind: regex
          value: '^logstash-'
        - filtertype: age
          direction: older
          timestring: '%Y.%m.%d.%H'
          source: name
          unit: {{ $resultRetentionValues.logstash.unit  | quote }}
          unit_count: {{ $resultRetentionValues.logstash.count }}
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
      3:
        action: delete_indices
        description: "Delete event indices older than {{ $resultRetentionValues.events.count }} {{ $resultRetentionValues.events.unit }} (based on index creation date)."
        filters:
        - filtertype: pattern
          kind: regex
          value: '^kubernetes_events-'
        - filtertype: age
          direction: older
          timestring: '%Y.%m.%d'
          source: name
          unit: {{ $resultRetentionValues.events.unit | quote }}
          unit_count: {{ $resultRetentionValues.events.count }}
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
      4:
        action: delete_indices
        description: "Delete notification indices older than {{ $resultRetentionValues.notifications.count }} {{ $resultRetentionValues.notifications.unit }} (based on index creation date)."
        filters:
        - filtertype: pattern
          kind: regex
          value: '^notification-'
        - filtertype: age
          direction: older
          timestring: '%Y.%m.%d'
          source: name
          unit: {{ $resultRetentionValues.notifications.unit | quote }}
          unit_count: {{ $resultRetentionValues.notifications.count }}
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
{{- if .Values.logging.rotateOldDataOnStorageWatermark | default .Values.elasticsearch.rotateOldDataOnStorageWatermark }}
      5:
        action: delete_indices
        description: "Delete indices to free storage space up to 75% (rounded up) of cluster total capacity in attempt to satisfy OpenSearch's storage low watermark (default: 85%)"
        filters:
        - filtertype: pattern
          kind: regex
          value: '^\.'
          exclude: true
        - filtertype: space
          disk_space: {{ div (mul 5 (mul $esReplicas (trimSuffix "G" (trimSuffix "Gi" (.Values.logging.persistentVolumeClaimSize | default .Values.elasticsearch.persistentVolumeClaimSize) )))) 20 }}
          use_age: true
          source: creation_date
          reverse: true
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
{{- end }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "curator") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- end }}
