{{- define "grafana" -}}
{{/* https://grafana.com/docs/grafana/latest/administration/configuration/#level */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "critical") "component" "grafana" | include "stacklight.logLevel" -}}
adminPassword: admin
enableOpensearchDashboardsLinks: {{ .Values.logging.enabled }}
sidecar_datasources:
  prometheus:
    type: prometheus
    isDefault: true
{{- $mimirEnabled := and .Values.cortexDev.enabled .Values.cortexDev.mimir }}
{{- if $mimirEnabled }}
    url: http://mimir-nginx/prometheus
{{- else if .Values.cortexDev.enabled }}
    url: http://cortex-nginx/api/prom
{{- else }}
    url: http://prometheus-relay
{{- end }}

{{- $lokiEnabled := and .Values.cortexDev.enabled .Values.logging.enabled .Values.cortexDev.loki.enabled }}
{{- if or .Values.cortexDev.enabled $mimirEnabled $lokiEnabled }}
datasources:
  datasources.yaml:
    apiVersion: 1
    datasources:
  {{- if $mimirEnabled }}
    - name: Mimir-Alertmanager
      type: alertmanager
      access: proxy
      url: http://mimir-nginx/alertmanager
      jsonData:
        implementation: prometheus
  {{- else if .Values.cortexDev.enabled }}
    - name: Cortex-Alertmanager
      type: alertmanager
      access: proxy
      url: http://cortex-nginx/api/prom
  {{- end }}
  {{- if $lokiEnabled }}
    - name: Loki
      type: loki
      access: proxy
      url: http://loki-query-frontend:3100
  {{- end }}
{{- end }}
podAnnotations:
  prometheus.io/port: "3000"
  prometheus.io/scrape: "true"
{{- if .Values.mke.enabled }}
rbac:
  pspUseAppArmor: false
{{- end }}
dashboards:
  default:
  {{- $isMimir := and .Values.cortexDev.enabled .Values.cortexDev.mimir }}
  {{- $isCortex := and .Values.cortexDev.enabled (not .Values.cortexDev.mimir) }}
  {{- if or .Values.mke.enabled (or $isCortex (and $isMimir .Values.highAvailabilityEnabled)) .Values.openstack.enabled }}
    etcd:
      file: dashboards/etcd.json
  {{- end }}
  {{- if or (and .Values.cortexDev.enabled .Values.cortexDev.memcached.enabled) .Values.openstack.enabled }}
    memcached:
      file: dashboards/memcached.json
  {{- end }}
  {{- if .Values.cortexDev.enabled }}
    minio:
      file: dashboards/minio.json
    {{- if .Values.cortexDev.mimir }}
    mimir:
      file: dashboards/mimir.json
    mimir-alertmanager:
      file: dashboards/mimir-alertmanager.json
    mimir-compactor:
      file: dashboards/mimir-compactor.json
    mimir-queries:
      file: dashboards/mimir-queries.json
    mimir-reads:
      file: dashboards/mimir-reads.json
    mimir-ruler:
      file: dashboards/mimir-ruler.json
    mimir-writes:
      file: dashboards/mimir-writes.json
    {{- end }}
  {{- else }}
    alertmanager:
      file: dashboards/alertmanager.json
    relay:
      file: dashboards/relay.json
  {{- end }}
  {{- if .Values.calico.enabled }}
    kubernetes-calico:
      file: dashboards/kubernetes-calico.json
  {{- end }}
  {{- if .Values.ceph.enabled }}
    ceph-cluster:
      file: dashboards/ceph-cluster.json
    ceph-nodes:
      file: dashboards/ceph-nodes.json
    ceph-osds:
      file: dashboards/ceph-osds.json
    ceph-pools:
      file: dashboards/ceph-pools.json
  {{- end }}
  {{- if .Values.ironic.enabled }}
    ironic-bm:
      file: dashboards/ironic-bm.json
  {{- end }}
  {{- if .Values.ipmiExporter.enabled }}
    ipmi:
      file: dashboards/ipmi.json
  {{- end }}
  {{- if .Values.logging.enabled }}
    opensearch:
      file: dashboards/opensearch.json
  {{- end }}
    grafana:
      file: dashboards/grafana.json
    kubernetes-cluster:
      file: dashboards/kubernetes-cluster.json
    kubernetes-containers:
      file: dashboards/kubernetes-containers.json
    kubernetes-deployments:
      file: dashboards/kubernetes-deployments.json
    kubernetes-namespaces:
      file: dashboards/kubernetes-namespaces.json
    kubernetes-nodes:
      file: dashboards/kubernetes-nodes.json
    kubernetes-pods:
      file: dashboards/kubernetes-pods.json
    system:
      file: dashboards/system.json
    postgresql:
      file: dashboards/postgresql.json
    prometheus:
      file: dashboards/prometheus.json
  {{- if .Values.openstack.enabled }}
    mysql:
      file: dashboards/mysql.json
    cinder:
      file: dashboards/cinder.json
    glance:
      file: dashboards/glance.json
    {{- if .Values.openstack.gnocchi.enabled }}
    gnocchi:
      file: dashboards/gnocchi.json
    {{- end }}
    heat:
      file: dashboards/heat.json
    {{- if .Values.openstack.ironic.enabled }}
    ironic-openstack:
      file: dashboards/ironic-openstack.json
    {{- end }}
    keystone:
      file: dashboards/keystone.json
    {{- if and (not .Values.tungstenFabricMonitoring.enabled) (.Values.openstack.arpingCheck.enabled) }}
    kpi-downtime:
      file: dashboards/kpi-downtime.json
    {{- end }}
    {{- if .Values.logging.enabled }}
    kpi-provisioning:
      file: dashboards/kpi-provisioning.json
    {{- end }}
    neutron:
    {{- if .Values.tungstenFabricMonitoring.enabled }}
      file: dashboards/neutron-tungsten-fabric.json
    {{- else }}
      file: dashboards/neutron.json
    {{- end }}
    nova-availability-zones:
      file: dashboards/nova-availability-zones.json
    nova-hypervisor-overview:
      file: dashboards/nova-hypervisor-overview.json
    nova-overview:
      file: dashboards/nova-overview.json
    nova-instances:
      file: dashboards/nova-instances.json
    nova-tenants:
      file: dashboards/nova-tenants.json
    nova-users:
      file: dashboards/nova-users.json
    nova-utilization:
      file: dashboards/nova-utilization.json
    openstack-overview:
      file: dashboards/openstack-overview.json
    nginx-ingress-controller:
      file: dashboards/nginx-ingress-controller.json
  {{- end }}
  {{- if or .Values.openstack.enabled .Values.tungstenFabricMonitoring.enabled }}
    rabbitmq:
      file: dashboards/rabbitmq.json
  {{- end }}
  {{- if .Values.tungstenFabricMonitoring.enabled }}
    cassandra:
      file: dashboards/cassandra.json
    kafka:
      file: dashboards/kafka.json
    redis:
      file: dashboards/redis.json
    tungsten-fabric-controller:
      file: dashboards/tungsten-fabric-controller.json
    tungsten-fabric-vrouter:
      file: dashboards/tungsten-fabric-vrouter.json
    zookeeper:
      file: dashboards/zookeeper.json
  {{- end }}
  {{- if .Values.telemetry.telemeterServer.enabled }}
    clusters-overview:
      file: dashboards/clusters-overview.json
    telemeter-server:
      file: dashboards/telemeter-server.json
  {{- end }}
  {{- if .Values.mke.enabled }}
    mke-cluster:
      file: dashboards/mke-cluster.json
    mke-containers:
      file: dashboards/mke-containers.json
  {{- end }}
  {{- if .Values.refapp.enabled }}
    reference-application:
      file: dashboards/reference-application.json
  {{- end }}
    mcc-applications-performance:
      file: dashboards/mcc-applications-performance.json
grafana.ini:
  {{- if .Values.cortexDev.enabled }}
  panels:
    enable_alpha: true
  feature_toggles:
    enable: ngalert
  {{- end }}
  dashboards:
    default_home_dashboard_path: /var/lib/grafana/dashboards/default/{{ .Values.grafana.homeDashboard }}.json
  auth:
    disable_login_form: {{ .Values.grafana.loginFormDisabled }}
  auth.anonymous:
    enabled: {{ .Values.grafana.anonymousAuthEnabled }}
    org_role: Admin
{{- if .Values.grafana.ldap.enabled }}
  auth.ldap:
    enabled: true
    allow_sign_up: true
    config_file: /etc/grafana/ldap.toml
{{- end }}
  database:
    type: postgres
    host: {{ include "stacklight.currentPatroni" . }}
    port: "5432"
    name: grafana
    user: grafana
    password: grafanadb
{{- if $logLevel }}
  log:
    level: {{ $logLevel | quote }}
{{- end }}
{{- if .Values.grafana.ldap.enabled }}
ldap:
  existingSecret: {{ .Values.grafana.ldap.existingSecret }}
  config: {{ .Values.grafana.ldap.config }}
{{- end }}

replicas: {{ get (include "stacklight.replicas" . | fromYaml) "grafana" }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "grafana") | nindent 2 }}

renderer:
  enabled: {{ .Values.grafana.renderer.enabled }}
  image: {{ include "stacklight.getImage" (dict "root" . "image" "grafanaImageRenderer" "flat" true) | quote }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "grafanaRenderer") | indent 2 }}
curlImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "alpineUtils") | nindent 2 }}
initChownData:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "alpineUtils") | nindent 4 }}
sidecar:
  image: {{ include "stacklight.getImage" (dict "root" . "image" "k8sSidecar" "flat" true) | quote }}
waitForDb:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "pgbouncer") | nindent 4 }}
deploymentStrategy:
  type: RollingUpdate
  rollingUpdate:
    maxUnavailable: 0
{{- if .Values.exposeLoadBalancers }}
service:
  type: LoadBalancer
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "grafana") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "grafana") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "grafana") }}
{{- end }}
