{{- define "loki" -}}
fullnameOverride: loki

distributor:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiDistributor" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiDistributor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}

ingester:
  {{- if .Values.highAvailabilityEnabled }}
  affinity: |
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "loki"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "ingester"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiIngester" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiIngester") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateful") | indent 2 }}
  persistence:
    enabled: true
    size: 20Gi
  {{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.lokiIngester }}
    {{- $storageClass := .Values.storage.defaultStorageClass }}
    {{- if .Values.storage.componentStorageClasses.lokiIngester }}
      {{- $storageClass = .Values.storage.componentStorageClasses.lokiIngester }}
    {{- end }}
    storageClass: "{{ $storageClass }}"
  {{- end }}

querier:
  {{- if .Values.highAvailabilityEnabled }}
  affinity: |
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "loki"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "query-scheduler"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiQuerier" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiQuerier") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateful") | indent 2 }}
  persistence:
    enabled: true
    size: 10Gi
  {{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.lokiQuerier }}
    {{- $storageClass := .Values.storage.defaultStorageClass }}
    {{- if .Values.storage.componentStorageClasses.lokiQuerier }}
      {{- $storageClass = .Values.storage.componentStorageClasses.lokiQuerier }}
    {{- end }}
    storageClass: "{{ $storageClass }}"
  {{- end }}

queryFrontend:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiQueryFrontend" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiQueryFrontend") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}

gateway:
  image:
    {{- $image := include "stacklight.getImage" (dict "root" . "image" "nginx") | fromYaml }}
    {{- $repo := splitn "/" 2 (index $image "repository") }}
    {{- $_ := set $image "registry" $repo._0 }}
    {{- $_ := set $image "repository" $repo._1 }}
    {{- $image | toYaml | nindent 4 }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiGateway" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiGateway") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}


tableManager:
  enabled: false


compactor:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiCompactor" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}


ruler:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "lokiRuler" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "lokiRuler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "lokiStateless") | indent 2 }}

loki:
  image:
    {{- $image := include "stacklight.getImage" (dict "root" . "image" "loki") | fromYaml }}
    {{- $repo := splitn "/" 2 (index $image "repository") }}
    {{- $_ := set $image "registry" $repo._0 }}
    {{- $_ := set $image "repository" $repo._1 }}
    {{- $image | toYaml | nindent 4 }}
  config: |
    auth_enabled: false
    common:
      compactor_address: loki-compactor:3100
    compactor:
      working_directory: /var/loki/compactor
      shared_store: s3
      compaction_interval: 10m
      retention_enabled: true
      retention_delete_delay: 2h
      delete_batch_size: 50
      retention_delete_worker_count: 10
    storage_config:
      aws:
        endpoint: "minio:9000"
        access_key_id: {{ include "minio.userAccessKeyId" . | quote }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . | quote }}
        bucketnames: loki-chunks
        s3forcepathstyle: true
        insecure: true
      boltdb_shipper:
        active_index_directory: /var/loki/index
        shared_store: s3
        cache_location: /var/loki/boltdb-cache
      {{- if .Values.cortexDev.memcached.enabled }}
      index_queries_cache_config:
        memcached_client:
          addresses: loki-memcached:11211
      {{- end }}
    schema_config:
      configs:
      - from: 2022-11-01
        store: boltdb-shipper
        object_store: s3
        schema: v11
        index:
          prefix: loki_index_
          period: 24h
    limits_config:
      {{- $loggingRetentionTime := merge (.Values.logging.retentionTime | default dict) (.Values.elasticsearch.retentionTime | default dict) }}
      {{- $loggingRetentionTime = (dict "retentionTime" $loggingRetentionTime "logstashRetentionTime" .Values.elasticsearch.logstashRetentionTime ) }}
      {{- $loggingRetentionTimeDefaultsSet := (include "stacklight.setRetentionDefaults" $loggingRetentionTime | fromYaml) }}
      retention_period: {{ $loggingRetentionTimeDefaultsSet.logstash }}
      enforce_metric_name: false
      per_stream_rate_limit: 512M
      per_stream_rate_limit_burst: 1024M
      cardinality_limit: 200000
      ingestion_burst_size_mb: 1000
      ingestion_rate_mb: 10000
      max_entries_limit_per_query: 1000000
      max_label_value_length: 20480
      max_label_name_length: 10240
      max_label_names_per_series: 300
      reject_old_samples: true
      reject_old_samples_max_age: 24h
      max_cache_freshness_per_query: 10m
      split_queries_by_interval: 15m
    server:
      http_listen_port: 3100
      grpc_server_max_recv_msg_size: 16777216
      grpc_server_max_send_msg_size: 16777216
    {{- if .Values.highAvailabilityEnabled }}
    distributor:
      ring:
        kvstore:
          store: etcd
          prefix: "loki/collectors/"
          etcd:
            endpoints: ["etcd:2379"]
    {{- end }}
    ingester:
      chunk_idle_period: 30m
      chunk_block_size: 262144
      chunk_encoding: snappy
      chunk_retain_period: 1m
      max_transfer_retries: 0
      wal:
        dir: /var/loki/wal
      lifecycler:
        final_sleep: 0s
        {{- if .Values.highAvailabilityEnabled }}
        ring:
          replication_factor: 1
          kvstore:
            store: etcd
            prefix: "loki/collectors/"
            etcd:
              endpoints: ["etcd:2379"]
        {{- end }}
    ruler:
      enable_api: true
      {{- if .Values.highAvailabilityEnabled }}
      ring:
        kvstore:
          store: etcd
          prefix: "loki/rulers/"
          etcd:
            endpoints: ["etcd:2379"]
      {{- end }}
      storage:
        type: s3
        s3:
          endpoint: "minio:9000"
          access_key_id: {{ include "minio.userAccessKeyId" . | quote }}
          secret_access_key: {{ include "minio.userSecretAccessKey" . | quote }}
          bucketnames: loki-notify
          s3forcepathstyle: true
          insecure: true
    chunk_store_config:
      max_look_back_period: 0s
      {{- if .Values.cortexDev.memcached.enabled }}
      chunk_cache_config:
        memcached_client:
          addresses: loki-memcached:11211
      {{- end }}
    query_range:
      align_queries_with_step: true
      max_retries: 5
      results_cache:
        cache:
        {{- if .Values.cortexDev.memcached.enabled }}
          memcached_client:
            addresses: loki-memcached:11211
        {{- else }}
          enable_fifocache: true
          fifocache:
            max_size_items: 1024
            validity: 24h
        {{- end }}
    frontend_worker:
      frontend_address: loki-query-frontend:9095
    frontend:
      log_queries_longer_than: 5s
      compress_responses: true
      tail_proxy_url: http://loki-querier:3100
{{- end -}}
