{{- define "memcached.common" -}}
image:
  {{- $image := include "stacklight.getImage" (dict "root" . "image" "memcached") | fromYaml }}
  {{- $repo := splitn "/" 2 (index $image "repository") }}
  {{- $_ := set $image "registry" $repo._0 }}
  {{- $_ := set $image "repository" $repo._1 }}
  {{- $image | toYaml | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
podAntiAffinityPreset: hard
architecture: high-availability
{{- else }}
podAntiAffinityPreset: soft
architecture: standalone
{{- end }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "memcached") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "memcached") }}
metrics:
  image:
    {{- $image := include "stacklight.getImage" (dict "root" . "image" "memcachedExporter") | fromYaml }}
    {{- $repo := splitn "/" 2 (index $image "repository") }}
    {{- $_ := set $image "registry" $repo._0 }}
    {{- $_ := set $image "repository" $repo._1 }}
    {{- $image | toYaml | nindent 4 }}
persistence:
  enabled: {{ .Values.cortexDev.memcached.persistent }}
  size: {{ .Values.cortexDev.memcached.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.memcached }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.memcached }}
    {{- $storageClass = .Values.storage.componentStorageClasses.memcached }}
  {{- end }}
global:
  storageClass: "{{ $storageClass }}"
{{- end }}
{{- end -}}

{{- define "memcached.cortexOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "memcachedCortex" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedCortex") }}
metrics:
  enabled: true
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedCortexExporter") | nindent 2 }}
{{- end -}}

{{- define "memcached.cortex" -}}
{{- $common := include "memcached.common" . | fromYaml }}
{{- $override := include "memcached.cortexOverride" . | fromYaml }}
{{- merge $override $common | toYaml }}
{{- end -}}

{{- define "memcached.lokiOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "memcachedLoki" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedLoki") }}
metrics:
  enabled: false
{{- end -}}

{{- define "memcached.loki" -}}
{{- $common := include "memcached.common" . | fromYaml }}
{{- $override := include "memcached.lokiOverride" . | fromYaml }}
{{- merge $override $common | toYaml }}
{{- end -}}
