{{- define "metricbeat" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warning" "error" "error" "crit" "error") "component" "metricbeat" | include "stacklight.logLevel" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "metricbeat") | nindent 2 }}

elasticsearchCheckImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "alpineUtils") | nindent 2 }}

{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "metricbeat") }}
deployment:
  enabled: true
  replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "metricbeat" }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "metricbeat") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "metricbeat") | nindent 2 }}
  config:
{{- if $logLevel }}
    logging.level: {{ $logLevel | quote }}
{{- end }}
    logging.metrics.enabled: false
    setup.template.name: "index_template_kubernetes_events"
    setup.template.settings:
      index.number_of_shards: 1
    {{- if .Values.highAvailabilityEnabled }}
      index.number_of_replicas: 2
    {{- else }}
      index.number_of_replicas: 0
    {{- end }}
    output.elasticsearch:
      index: "kubernetes_events-%{[agent.version]}-%{+yyyy.MM.dd}"
      hosts:
      - "http://opensearch-master:9200"

daemonset:
  enabled: false
  tolerations:
  - key: "node-role.kubernetes.io/master"
    operator: "Exists"
    effect: "NoSchedule"
  {{- if .Values.mke.enabled }}
  - key: "com.docker.ucp.manager"
    operator: "Exists"
    effect: "NoSchedule"
  {{- end }}
  {{- $tolerations := (concat .Values.tolerations.default .Values.tolerations.component.metricbeat) | uniq }}
  {{- if $tolerations }}
    {{ toYaml $tolerations | nindent 2 }}
  {{- end }}
{{- if .Values.nodeSelector.component.metricbeat }}
  nodeSelector:
    {{ toYaml .Values.nodeSelector.component.metricbeat | nindent 4 }}
{{- end }}
{{- end }}
