{{- define "mimir" -}}
nameOverride: mimir
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "mimir") | nindent 2 }}
configStorageType: Secret
mimir:
  config: |
    multitenancy_enabled: false
    limits:
      ruler_max_rules_per_rule_group: 400
      {{- if .Values.highAvailabilityEnabled }}
      accept_ha_samples: true
      {{- end }}
    activity_tracker:
      filepath: /data/metrics-activity.log
    alertmanager:
      data_dir: '/data'
      enable_api: true
      external_url: '/alertmanager'
      fallback_config_file: /opt/mimir/fallback.yml
      {{- if .Values.highAvailabilityEnabled }}
      sharding_ring:
        replication_factor: 2
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/alertmanagers/"
      {{- end }}
    alertmanager_storage:
      backend: s3
      s3:
        endpoint: minio:9000
        bucket_name: mimir-ruler
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true
    frontend_worker:
      {{- if eq (include "stacklight.mimir.scheduler-enabler" .) "true" }}
      scheduler_address: {{ "{{ template \"mimir.fullname\" . }}-query-scheduler-headless:{{ include \"mimir.serverGrpcListenPort\" . }}" }}
      {{- else }}
      frontend_address: {{ "{{ template \"mimir.fullname\" . }}-query-frontend-headless:{{ include \"mimir.serverGrpcListenPort\" . }}" }}
      {{- end }}
    frontend:
      log_queries_longer_than: 10s
      align_queries_with_step: true
      {{- if eq (include "stacklight.mimir.scheduler-enabler" .) "true" }}
      scheduler_address: {{ "{{ template \"mimir.fullname\" . }}-query-scheduler-headless:{{ include \"mimir.serverGrpcListenPort\" . }}" }}
      {{- end }}
    compactor:
      data_dir: "/data"
      {{- if .Values.highAvailabilityEnabled }}
      sharding_ring:
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/collectors/"
      {{- end }}
    {{- if .Values.highAvailabilityEnabled }}
    distributor:
      ha_tracker:
        enable_ha_tracker: true
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/ha-tracker/"
      ring:
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/collectors/"
    {{- end }}
    ingester:
      ring:
        final_sleep: 0s
        num_tokens: 512
        {{- if .Values.highAvailabilityEnabled }}
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/collectors/"
        {{- end }}
    ingester_client:
      grpc_client_config:
        max_recv_msg_size: 104857600
        max_send_msg_size: 104857600
    ruler:
      enable_api: true
      rule_path: '/data'
      alertmanager_url: dnssrvnoa+http://_http-metrics._tcp.{{ "{{ template \"mimir.fullname\" . }}" }}-alertmanager-headless/alertmanager
      {{- if .Values.highAvailabilityEnabled }}
      ring:
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/rulers/"
      {{- end }}
    ruler_storage:
      backend: s3
      s3:
        endpoint: minio:9000
        bucket_name: mimir-ruler
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true
    {{- if .Values.highAvailabilityEnabled }}
    store_gateway:
      sharding_ring:
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "mimir/collectors/"
    {{- end }}
    server:
      grpc_server_max_recv_msg_size: 104857600
      grpc_server_max_send_msg_size: 104857600
      grpc_server_max_concurrent_streams: 1000
    runtime_config:
      file: /var/{{ "{{ include \"mimir.name\" . }}" }}/runtime.yaml
    memberlist:
      abort_if_cluster_join_fails: false
      compression_enabled: false
      join_members:
      - {{ "{{ include \"mimir.fullname\" . }}" }}-gossip-ring
    blocks_storage:
      backend: s3
      tsdb:
        dir: /data/tsdb
      bucket_store:
        sync_dir: /data/tsdb-sync
        {{- if .Values.cortexDev.memcached.enabled }}
        chunks_cache:
          backend: memcached
          memcached:
            addresses: mimir-memcached:11211
            max_item_size: {{ "{{ .Values.memcached.maxItemMemory }}" }}
        index_cache:
          backend: memcached
          memcached:
            addresses: mimir-memcached:11211
            max_item_size: {{ "{{ (index .Values \"memcached-queries\").maxItemMemory }}" }}
        metadata_cache:
          backend: memcached
          memcached:
            addresses: mimir-memcached:11211
            max_item_size: {{ "{{ (index .Values \"memcached-metadata\").maxItemMemory }}" }}
        {{- end }}
      s3:
        endpoint: minio:9000
        bucket_name: mimir-tsdb
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true

alertmanager:
  enabled: true
  extraVolumes:
  - name: alertmanager-config
    configMap:
      name: stacklight-ng-alertmanager
      items:
      - key: fallback.yml
        path: fallback.yml
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  extraVolumeMounts:
  - name: alertmanager-config
    mountPath: /opt/mimir
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexAlertmanager" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexAlertmanager") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    size: 10Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexAlertManager }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}

compactor:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexCompactor" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  extraArgs:
    compactor.blocks-retention-period: {{ .Values.cortexDev.retentionTime.compactor }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexCompactor }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  persistentVolume:
    size: 20Gi

distributor:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexDistributor" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexDistributor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  extraArgs:
    {{- $ingestionRateLimit := include "stacklight.sizeBased" (dict "root" .Values.cortexDev.ingestion "key" "rateLimit" "size" .Values.clusterSize "small" 30000 "medium" 300000 "large" 3000000) }}
    {{- $ingestionBurstSize := include "stacklight.sizeBased" (dict "root" .Values.cortexDev.ingestion  "key" "burstSize" "size" .Values.clusterSize "small" 150000 "medium" 1500000 "large" 15000000) }}
    distributor.ingestion-rate-limit: {{ $ingestionRateLimit | quote }}
    distributor.ingestion-burst-size: {{ $ingestionBurstSize | quote }}
    {{- if .Values.highAvailabilityEnabled }}
    distributor.ha-tracker.enable: true
    distributor.ha-tracker.enable-for-all-users: true
    distributor.ha-tracker.cluster: mcc_cluster_id
    {{- end }}

ingester:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "mimir"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "ingester"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexIngester" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  extraArgs:
    blocks-storage.tsdb.retention-period: {{ .Values.cortexDev.retentionTime.ingester }}
    ingester.ring.replication-factor: 2
    ingester.max-global-series-per-user: {{ .Values.cortexDev.ingestion.maxSeries | int64 }}
    ingester.max-global-series-per-metric: {{ .Values.cortexDev.ingestion.maxSeries | int64 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexIngester") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    size: 50Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexIngester }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexIngester }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexIngester }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
overrides_exporter:
  enabled: false
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}

querier:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQuerier" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQuery") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

query_frontend:
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQueryFrontend" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQueryFrontend") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

query_scheduler:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "mimir"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "query-scheduler"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  enabled: {{ include "stacklight.mimir.scheduler-enabler" . }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQueryScheduler" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQueryScheduler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

ruler:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexRuler" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexRuler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

store_gateway:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexStoreGateway" }}
  {{- include "stacklight.mimir.securityContext" . | nindent 2 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexStoreGateway") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexStoreGateway }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}

nginx:
  enabled: true
  image:
    {{- $image := include "stacklight.getImage" (dict "root" . "image" "nginx") | fromYaml }}
    {{- $repo := splitn "/" 2 (index $image "repository") }}
    {{- $_ := set $image "registry" $repo._0 }}
    {{- $_ := set $image "repository" $repo._1 }}
    {{- $image | toYaml | nindent 4 }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexNginx" }}
# Disable creating MinIO by Mimir chart
minio:
  enabled: false
{{- end -}}
