{{- define "prometheus.nodeExporter" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "error") "component" "prometheusNodeExporter" | include "stacklight.logLevel" -}}
{{- $netDeviceExclude := .Values.nodeExporter.netDeviceExclude -}}
{{- $extraNetstatFields := .Values.nodeExporter.extraNetstatFields -}}
nodeExporter:
  extraArgs:
    {{- if $logLevel }}
    "log.level": {{ $logLevel | quote }}
    {{- end }}
    "path.rootfs": "/host/rootfs"
    {{- if .Values.nodeExporter.mountPointsExclude }}
    "collector.filesystem.mount-points-exclude": {{ .Values.nodeExporter.mountPointsExclude | quote }}
    {{- end }}
    {{- if $netDeviceExclude }}
    "collector.netclass.ignored-devices": {{ $netDeviceExclude | quote }}
    "collector.netdev.device-exclude": {{ $netDeviceExclude | quote }}
    {{- end }}
    "collector.netstat.fields": "^(.*_(InErrors|InErrs)|TcpExt_TCPSynRetrans|Tcp_(ActiveOpens|AttemptFails|EstabResets|InSegs|InCsumErrors|MaxConn|OutSegs|OutRsts|PassiveOpens|RetransSegs|CurrEstab)|Udp_(InCsumErrors|InDatagrams|OutDatagrams|NoPorts|RcvbufErrors|SndbufErrors
    {{- if $extraNetstatFields }}
      {{- range $fieldsItems := $extraNetstatFields -}}
      |{{ $fieldsItems }}
      {{- end }}
    {{- end -}}
    ))$"
    "collector.disable-defaults": ''
  {{- $collectorList := (tuple "arp" "conntrack" "cpu" "diskstats" "entropy" "filefd" "filesystem" "hwmon" "loadavg" "meminfo" "netclass" "netdev" "netstat" "stat" "sockstat" "textfile" "time" "timex" "uname" "vmstat") -}}
  {{- if .Values.nodeExporter.extraCollectorsEnabled }}
    {{- range $extraCollector :=  .Values.nodeExporter.extraCollectorsEnabled }}
    {{- if not (has $extraCollector $collectorList) }}
    {{- $collectorList = append $collectorList $extraCollector -}}
    {{- end }}
    {{- end }}
  {{- end }}
  {{- if and (not (has "bonding" $collectorList)) (has (lower .Values.provider) (list "baremetal" "equinixmetal" "equinixmetalv2")) }}
    {{- $collectorList = append $collectorList "bonding" -}}
  {{- end }}
  {{- range $collectorList  }}
    "collector.{{ . }}": ''
  {{- end }}
  extraHostPathMounts:
  - name: rootfs
    mountPath: /host/rootfs
    hostPath: /
    readOnly: true
  tolerations:
  - key: "node-role.kubernetes.io/master"
    operator: "Exists"
    effect: "NoSchedule"
  {{- if .Values.mke.enabled }}
  - key: "com.docker.ucp.manager"
    operator: "Exists"
    effect: "NoSchedule"
  {{- end }}
  {{- $tolerations := (concat .Values.tolerations.default .Values.tolerations.component.prometheusNodeExporter) | uniq }}
  {{- if $tolerations }}
    {{ toYaml $tolerations | nindent 2 }}
  {{- end }}
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "nodeExporter") | nindent 4 }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "nodeExporter") | nindent 2 }}
  {{- if .Values.nodeSelector.component.prometheusNodeExporter }}
  nodeSelector:
    {{ toYaml .Values.nodeSelector.component.prometheusNodeExporter | nindent 4 }}
  {{- end }}
  updateStrategy:
    type: RollingUpdate
    rollingUpdate:
      maxUnavailable: 50%
{{- end -}}
