{{- define "telemeterClient" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "fatal") "component" "telemeterClient" | include "stacklight.logLevel" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "telemeterClient" }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "telemeter") | nindent 2 }}
client:
  id: {{ .Values.clusterId }}
  to: {{ .Values.telemetry.telemeterClient.to }}
  interval: {{ .Values.telemetry.telemeterClient.interval }}
  limitBytes: {{ int64 .Values.telemetry.telemeterClient.limitBytes }}
  token:
    value: {{ .Values.telemetry.telemeterClient.token.value | quote }}
    secretName: {{ .Values.telemetry.telemeterClient.token.name | quote }}
  verbose: {{ .Values.telemetry.telemeterClient.verbose }}
extraArgs:
{{- if $logLevel }}
  - --log-level={{ $logLevel | quote }}
{{- end }}
match:
{{- $idKey := .Values.telemetry.clusterIdLabelInjection.key }}
{{- if .Values.telemetry.clusterIdLabelInjection.enabled }}
  - --match={__name__=~"telemetry:.+",{{ $idKey }}!=""}
{{- else }}
  - --match={__name__=~"telemetry:.+"}
{{- end }}
{{- range .Values.telemetry.telemeterClient.matchRules }}
  - --match={{ . }}
{{- end }}
{{- if ne $idKey "cluster_id" }}
httpProxyDiscovery:
  enabled: {{ .Values.global.proxy.enabled }}
  secretName: {{ .Values.global.proxy.secretName }}
  checksum: {{ .Values.global.proxy.hash }}
  ssl: {{ .Values.global.proxy.ssl }}
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "telemeterClient") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "telemeterClient") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "telemeterClient") }}
tls:
  enabled: {{ .Values.telemetry.telemeterClient.tls.enabled }}
  secretName: {{ .Values.telemetry.telemeterClient.tls.secretName }}
  secretChecksum: {{ .Values.telemetry.telemeterClient.tls.secretChecksum }}
{{- end }}
